aboutsummaryrefslogtreecommitdiffstats
path: root/src/output_control.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/output_control.h')
-rw-r--r--src/output_control.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/src/output_control.h b/src/output_control.h
index 2b88d4103..f0e317d6e 100644
--- a/src/output_control.h
+++ b/src/output_control.h
@@ -72,11 +72,17 @@ audio_output_drain_async(struct audio_output *ao);
/**
* Clear the "allow_play" flag and send the "CANCEL" command
* asynchronously. To finish the operation, the caller has to set the
* "allow_play" flag and signal the thread.
*/
void audio_output_cancel(struct audio_output *ao);
+/**
+ * Set the "allow_play" and signal the thread.
+ */
+void
+audio_output_allow_play(struct audio_output *ao);
+
void audio_output_close(struct audio_output *ao);
/**
@@ -72,11 +72,17 @@ audio_output_drain_async(struct audio_output *ao);
/**
* Clear the "allow_play" flag and send the "CANCEL" command
- * asynchronously. To finish the operation, the caller has to set the
- * "allow_play" flag and signal the thread.
+ * asynchronously. To finish the operation, the caller has to call
+ * audio_output_allow_play().
*/
void audio_output_cancel(struct audio_output *ao);